@@ -29,6 +29,8 @@ import (
 	. "github.com/onsi/gomega"
 	"github.com/pborman/uuid"
 
+	"kubevirt.io/kubevirt/tests/util"
+
 	v1 "kubevirt.io/client-go/api/v1"
 
 	"kubevirt.io/client-go/kubecli"
@@ -42,39 +44,36 @@ import (
 var _ = Describe("[Serial][rfe_id:899][crit:medium][vendor:cnv-qe@redhat.com][level:component][sig-compute]Config", func() {
 
 	var virtClient kubecli.KubevirtClient
-	var CheckIsoVolumeSizes func(vmi *v1.VirtualMachineInstance)
 
-	tests.BeforeAll(func() {
-		CheckIsoVolumeSizes = func(vmi *v1.VirtualMachineInstance) {
-			pod := tests.GetRunningPodByVirtualMachineInstance(vmi, vmi.Namespace)
+	var CheckIsoVolumeSizes = func(vmi *v1.VirtualMachineInstance) {
+		pod := tests.GetRunningPodByVirtualMachineInstance(vmi, vmi.Namespace)
 
-			for _, volume := range vmi.Spec.Volumes {
-				var path = ""
-				if volume.ConfigMap != nil {
-					path = config.GetConfigMapDiskPath(volume.Name)
-					By(fmt.Sprintf("Checking ConfigMap at '%s' is 4k-block fs compatible", path))
-				}
-				if volume.Secret != nil {
-					path = config.GetSecretDiskPath(volume.Name)
-					By(fmt.Sprintf("Checking Secret at '%s' is 4k-block fs compatible", path))
-				}
-				if len(path) > 0 {
-					cmdCheck := []string{"stat", "--printf='%s'", path}
-					out, err := tests.ExecuteCommandOnPod(virtClient, pod, "compute", cmdCheck)
-					Expect(err).NotTo(HaveOccurred())
-					size, err := strconv.Atoi(strings.Trim(out, "'"))
-					Expect(err).NotTo(HaveOccurred())
-					Expect(size % 4096).To(Equal(0))
-				}
+		for _, volume := range vmi.Spec.Volumes {
+			var path = ""
+			if volume.ConfigMap != nil {
+				path = config.GetConfigMapDiskPath(volume.Name)
+				By(fmt.Sprintf("Checking ConfigMap at '%s' is 4k-block fs compatible", path))
+			}
+			if volume.Secret != nil {
+				path = config.GetSecretDiskPath(volume.Name)
+				By(fmt.Sprintf("Checking Secret at '%s' is 4k-block fs compatible", path))
+			}
+			if len(path) > 0 {
+				cmdCheck := []string{"stat", "--printf='%s'", path}
+				out, err := tests.ExecuteCommandOnPod(virtClient, pod, "compute", cmdCheck)
+				Expect(err).NotTo(HaveOccurred())
+				size, err := strconv.Atoi(strings.Trim(out, "'"))
+				Expect(err).NotTo(HaveOccurred())
+				Expect(size % 4096).To(Equal(0))
 			}
 		}
-	})
+	}
 
 	BeforeEach(func() {
 		var err error
 
 		virtClient, err = kubecli.GetKubevirtClient()
-		tests.PanicOnError(err)
+		util.PanicOnError(err)
 
 		tests.BeforeTestCleanup()
 	})
@@ -104,8 +103,6 @@ var _ = Describe("[Serial][rfe_id:899][crit:medium][vendor:cnv-qe@redhat.com][le
 			})
 
 			It("[test_id:782]Should be the fs layout the same for a pod and vmi", func() {
-				tests.SkipPVCTestIfRunnigOnKindInfra()
-
 				expectedOutput := "value1value2value3"
 
 				By("Running VMI")
@@ -115,7 +112,7 @@ var _ = Describe("[Serial][rfe_id:899][crit:medium][vendor:cnv-qe@redhat.com][le
 				CheckIsoVolumeSizes(vmi)
 
 				By("Checking if ConfigMap has been attached to the pod")
-				vmiPod := tests.GetRunningPodByVirtualMachineInstance(vmi, tests.NamespaceTestDefault)
+				vmiPod := tests.GetRunningPodByVirtualMachineInstance(vmi, util.NamespaceTestDefault)
 				podOutput, err := tests.ExecuteCommandOnPod(
 					virtClient,
 					vmiPod,
@@ -200,8 +197,6 @@ var _ = Describe("[Serial][rfe_id:899][crit:medium][vendor:cnv-qe@redhat.com][le
 			})
 
 			It("[test_id:779]Should be the fs layout the same for a pod and vmi", func() {
-				tests.SkipPVCTestIfRunnigOnKindInfra()
-
 				expectedOutput := "adminredhat"
 
 				By("Running VMI")
@@ -211,7 +206,7 @@ var _ = Describe("[Serial][rfe_id:899][crit:medium][vendor:cnv-qe@redhat.com][le
 				CheckIsoVolumeSizes(vmi)
 
 				By("Checking if Secret has been attached to the pod")
-				vmiPod := tests.GetRunningPodByVirtualMachineInstance(vmi, tests.NamespaceTestDefault)
+				vmiPod := tests.GetRunningPodByVirtualMachineInstance(vmi, util.NamespaceTestDefault)
 				podOutput, err := tests.ExecuteCommandOnPod(
 					virtClient,
 					vmiPod,
@@ -277,15 +272,13 @@ var _ = Describe("[Serial][rfe_id:899][crit:medium][vendor:cnv-qe@redhat.com][le
 		serviceAccountPath := config.ServiceAccountSourceDir
 
 		It("[test_id:998]Should be the namespace and token the same for a pod and vmi", func() {
-			tests.SkipPVCTestIfRunnigOnKindInfra()
-
 			By("Running VMI")
 			vmi := tests.NewRandomVMIWithServiceAccount("default")
 			tests.RunVMIAndExpectLaunch(vmi, 90)
 			CheckIsoVolumeSizes(vmi)
 
 			By("Checking if ServiceAccount has been attached to the pod")
-			vmiPod := tests.GetRunningPodByVirtualMachineInstance(vmi, tests.NamespaceTestDefault)
+			vmiPod := tests.GetRunningPodByVirtualMachineInstance(vmi, util.NamespaceTestDefault)
 			namespace, err := tests.ExecuteCommandOnPod(
 				virtClient,
 				vmiPod,
@@ -296,7 +289,7 @@ var _ = Describe("[Serial][rfe_id:899][crit:medium][vendor:cnv-qe@redhat.com][le
 			)
 
 			Expect(err).To(BeNil())
-			Expect(namespace).To(Equal(tests.NamespaceTestDefault))
+			Expect(namespace).To(Equal(util.NamespaceTestDefault))
 
 			token, err := tests.ExecuteCommandOnPod(
 				virtClient,
@@ -319,7 +312,7 @@ var _ = Describe("[Serial][rfe_id:899][crit:medium][vendor:cnv-qe@redhat.com][le
 				&expect.BSnd{S: "echo $?\n"},
 				&expect.BExp{R: console.RetValue("0")},
 				&expect.BSnd{S: "cat /mnt/namespace\n"},
-				&expect.BExp{R: tests.NamespaceTestDefault},
+				&expect.BExp{R: util.NamespaceTestDefault},
 				&expect.BSnd{S: "tail -c 20 /mnt/token\n"},
 				&expect.BExp{R: token},
 			}, 200)).To(Succeed())
@@ -370,9 +363,9 @@ var _ = Describe("[Serial][rfe_id:899][crit:medium][vendor:cnv-qe@redhat.com][le
 
 				By("Running VMI")
 
-				vmi := tests.NewRandomVMIWithEphemeralDiskAndUserdataHighMemory(
+				vmi := tests.NewRandomVMIWithEphemeralDiskHighMemory(
 					cd.ContainerDiskFor(
-						cd.ContainerDiskFedora), "#!/bin/bash\necho \"fedora\" | passwd fedora --stdin\n")
+						cd.ContainerDiskFedoraTestTooling))
 				tests.AddConfigMapDisk(vmi, configMapName, configMapName)
 				tests.AddSecretDisk(vmi, secretName, secretName)
 				tests.AddConfigMapDiskWithCustomLabel(vmi, configMapName, "random1", "configlabel")
@@ -387,7 +380,7 @@ var _ = Describe("[Serial][rfe_id:899][crit:medium][vendor:cnv-qe@redhat.com][le
 				CheckIsoVolumeSizes(vmi)
 
 				By("Checking if ConfigMap has been attached to the pod")
-				vmiPod := tests.GetRunningPodByVirtualMachineInstance(vmi, tests.NamespaceTestDefault)
+				vmiPod := tests.GetRunningPodByVirtualMachineInstance(vmi, util.NamespaceTestDefault)
 				podOutputCfgMap, err := tests.ExecuteCommandOnPod(
 					virtClient,
 					vmiPod,
@@ -408,7 +401,7 @@ var _ = Describe("[Serial][rfe_id:899][crit:medium][vendor:cnv-qe@redhat.com][le
 					// mount ConfigMap image
 					&expect.BSnd{S: "sudo su -\n"},
 					&expect.BExp{R: console.PromptExpression},
-					&expect.BSnd{S: "mount /dev/vdc /mnt\n"},
+					&expect.BSnd{S: "mount /dev/vdb /mnt\n"},
 					&expect.BExp{R: console.PromptExpression},
 					&expect.BSnd{S: "echo $?\n"},
 					&expect.BExp{R: console.RetValue("0")},
@@ -433,7 +426,7 @@ var _ = Describe("[Serial][rfe_id:899][crit:medium][vendor:cnv-qe@redhat.com][le
 
 				Expect(console.SafeExpectBatch(vmi, []expect.Batcher{
 					// mount Secret image
-					&expect.BSnd{S: "mount /dev/vdd /mnt\n"},
+					&expect.BSnd{S: "mount /dev/vdc /mnt\n"},
 					&expect.BExp{R: console.PromptExpression},
 					&expect.BSnd{S: "echo $?\n"},
 					&expect.BExp{R: console.RetValue("0")},
@@ -443,13 +436,13 @@ var _ = Describe("[Serial][rfe_id:899][crit:medium][vendor:cnv-qe@redhat.com][le
 
 				By("checking that all disk labels match the expectations")
 				Expect(console.SafeExpectBatch(vmi, []expect.Batcher{
+					&expect.BSnd{S: "blkid -s LABEL -o value /dev/vdb\n"},
+					&expect.BExp{R: "cfgdata"}, // default value
 					&expect.BSnd{S: "blkid -s LABEL -o value /dev/vdc\n"},
 					&expect.BExp{R: "cfgdata"}, // default value
 					&expect.BSnd{S: "blkid -s LABEL -o value /dev/vdd\n"},
-					&expect.BExp{R: "cfgdata"}, // default value
-					&expect.BSnd{S: "blkid -s LABEL -o value /dev/vde\n"},
 					&expect.BExp{R: "configlabel"}, // custom value
-					&expect.BSnd{S: "blkid -s LABEL -o value /dev/vdf\n"},
+					&expect.BSnd{S: "blkid -s LABEL -o value /dev/vde\n"},
 					&expect.BExp{R: "secretlabel"}, // custom value
 				}, 200)).To(Succeed())
 			})
@@ -489,16 +482,16 @@ var _ = Describe("[Serial][rfe_id:899][crit:medium][vendor:cnv-qe@redhat.com][le
 				expectedPublicKey := string(publicKeyBytes)
 
 				By("Running VMI")
-				vmi := tests.NewRandomVMIWithEphemeralDiskAndUserdataHighMemory(
+				vmi := tests.NewRandomVMIWithEphemeralDiskHighMemory(
 					cd.ContainerDiskFor(
-						cd.ContainerDiskFedora), "#!/bin/bash\necho \"fedora\" | passwd fedora --stdin\n")
+						cd.ContainerDiskFedoraTestTooling))
 				tests.AddSecretDisk(vmi, secretName, secretName)
 				vmi = tests.RunVMIAndExpectLaunch(vmi, 90)
 
 				CheckIsoVolumeSizes(vmi)
 
 				By("Checking if Secret has been attached to the pod")
-				vmiPod := tests.GetRunningPodByVirtualMachineInstance(vmi, tests.NamespaceTestDefault)
+				vmiPod := tests.GetRunningPodByVirtualMachineInstance(vmi, util.NamespaceTestDefault)
 				podOutput1, err := tests.ExecuteCommandOnPod(
 					virtClient,
 					vmiPod,
@@ -551,8 +544,6 @@ var _ = Describe("[Serial][rfe_id:899][crit:medium][vendor:cnv-qe@redhat.com][le
 		expectedOutput := testLabelKey + "=" + "\"" + testLabelVal + "\""
 
 		It("[test_id:790]Should be the namespace and token the same for a pod and vmi", func() {
-			tests.SkipPVCTestIfRunnigOnKindInfra()
-
 			By("Running VMI")
 			vmi := tests.NewRandomVMIWithPVC(tests.DiskAlpineHostPath)
 			//Add the testing label to the VMI
@@ -567,7 +558,7 @@ var _ = Describe("[Serial][rfe_id:899][crit:medium][vendor:cnv-qe@redhat.com][le
 			CheckIsoVolumeSizes(vmi)
 
 			By("Checking if DownwardAPI has been attached to the pod")
-			vmiPod := tests.GetRunningPodByVirtualMachineInstance(vmi, tests.NamespaceTestDefault)
+			vmiPod := tests.GetRunningPodByVirtualMachineInstance(vmi, util.NamespaceTestDefault)
 			podOutput, err := tests.ExecuteCommandOnPod(
 				virtClient,
 				vmiPod,
